@@ -2,8 +2,8 @@
 
    This file is part of the UPX executable compressor.
 
-   Copyright (C) 1996-2009 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 1996-2009 Laszlo Molnar
+   Copyright (C) 1996-2013 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2013 Laszlo Molnar
    All Rights Reserved.
 
    UPX and the UCL library are free software; you can redistribute them
@@ -47,10 +47,11 @@ void lzma_compress_config_t::reset()
 }
 
 
-#if !defined(WITH_LZMA)
+#if !(WITH_LZMA)
 extern int compress_lzma_dummy;
 int compress_lzma_dummy = 0;
 #else
+#define opt compress_lzma_opt
 
 #undef USE_LZMA_PROPERTIES
 
@@ -229,6 +230,7 @@ error:
 **************************************************************************/
 
 #if (WITH_LZMA >= 0x461)
+#define _7ZIP_ST 1
 #define kLiteralNextStates kLiteralNextStates_enc
 #include "C/LzmaEnc.h"
 #include "C/LzmaEnc.c"
@@ -290,7 +292,7 @@ int upx_lzma_compress      ( const upx_bytep src, unsigned  src_len,
     unsigned char props_buf[LZMA_PROPS_SIZE];
     SizeT props_buf_size; props_buf_size = LZMA_PROPS_SIZE;
 
-#if defined(USE_LZMA_PROPERTIES)
+#if (USE_LZMA_PROPERTIES)
     if (dst_avail < 1)
         goto error;
     dst[0] = 0; // filled below
@@ -311,8 +313,8 @@ int upx_lzma_compress      ( const upx_bytep src, unsigned  src_len,
     assert(x_len <= dst_avail);
     *dst_len += x_len;
     if (rh == SZ_OK) {
-#if defined(USE_LZMA_PROPERTIES)
-        dst[-1] = probs_buf[0];
+#if (USE_LZMA_PROPERTIES)
+        dst[-1] = props_buf[0];
 #endif
         r = UPX_E_OK;
     }
@@ -351,6 +353,7 @@ namespace MyLzma {
 
 struct InStream: public ISequentialInStream, public CMyUnknownImp
 {
+    virtual ~InStream() { }
     MY_UNKNOWN_IMP
     const Byte *b_buf; size_t b_size; size_t b_pos;
     void Init(const Byte *data, size_t size) {
@@ -371,6 +374,7 @@ STDMETHODIMP InStream::Read(void *data, UInt32 size, UInt32 *processedSize)
 
 struct OutStream : public ISequentialOutStream, public CMyUnknownImp
 {
+    virtual ~OutStream() { }
     MY_UNKNOWN_IMP
     Byte *b_buf; size_t b_size; size_t b_pos; bool overflow;
     void Init(Byte *data, size_t size) {
@@ -396,6 +400,7 @@ STDMETHODIMP OutStream::Write(const void *data, UInt32 size, UInt32 *processedSi
 
 struct ProgressInfo : public ICompressProgressInfo, public CMyUnknownImp
 {
+    virtual ~ProgressInfo() { }
     MY_UNKNOWN_IMP
     STDMETHOD(SetRatioInfo)(const UInt64 *inSize, const UInt64 *outSize);
     upx_callback_p cb;
@@ -411,7 +416,7 @@ STDMETHODIMP ProgressInfo::SetRatioInfo(const UInt64 *inSize, const UInt64 *outS
 } // namespace
 
 
-#if (ACC_CC_INTELC) && defined(__linux__)
+#if (ACC_CC_INTELC_GNUC)
 #  pragma warning(disable: 424)         // #424: extra ";" ignored
 #endif
 
@@ -512,7 +517,7 @@ int upx_lzma_compress      ( const upx_bytep src, unsigned  src_len,
         goto error;
     }
     assert(os.b_pos == 5);
-#if defined(USE_LZMA_PROPERTIES)
+#if (USE_LZMA_PROPERTIES)
     os.b_pos = 1;
 #else
     os.b_pos = 0;
@@ -545,7 +550,7 @@ int upx_lzma_compress      ( const upx_bytep src, unsigned  src_len,
     }
 
 error:
-    *dst_len = os.b_pos;
+    *dst_len = (unsigned) os.b_pos;
     //printf("\nlzma_compress: %d: %u %u %u %u %u, %u - > %u\n", r, res->pos_bits, res->lit_pos_bits, res->lit_context_bits, res->dict_size, res->num_probs, src_len, *dst_len);
     //printf("%u %u %u\n", is.__m_RefCount, os.__m_RefCount, progress.__m_RefCount);
     return r;
@@ -585,7 +590,7 @@ int upx_lzma_decompress    ( const upx_bytep src, unsigned  src_len,
     SRes rh;
     ELzmaStatus status;
 
-#if defined(USE_LZMA_PROPERTIES)
+#if (USE_LZMA_PROPERTIES)
     rh = LzmaProps_Decode(&s.Properties, src, src_len);
     if (rh != 0)
         goto error;
@@ -640,7 +645,7 @@ int upx_lzma_decompress    ( const upx_bytep src, unsigned  src_len,
     }
 error:
     *dst_len = s.dicPos;
-//    LzmaDec_Free(&s, &cba); // FIXME - why does this crash ???
+    LzmaDec_FreeProbs(&s, &cba);
     return r;
 #undef Properties
 }
@@ -683,7 +688,7 @@ int upx_lzma_decompress    ( const upx_bytep src, unsigned  src_len,
     int r = UPX_E_ERROR;
     int rh;
 
-#if defined(USE_LZMA_PROPERTIES)
+#if (USE_LZMA_PROPERTIES)
     if (src_len < 2)
         goto error;
     rh = LzmaDecodeProperties(&s.Properties, src, src_len);
