@@ -608,7 +608,7 @@ protected:
     Mach_segment_command *rawmseg;  // as input, with sections
     Mach_segment_command *msegcmd;  // LC_SEGMENT first, without sections
     unsigned o_routines_cmd;  // file offset to LC_ROUINTES
-    acc_uint64l_t prev_init_address;
+    upx_uint64_t prev_init_address;
     Mach_header mhdri;
 
     Mach_header mhdro;
